@media screen and (max-width: 1024px) {
}
@media screen and (max-width: 768px) {
 .banner-text {
 padding-top: 30%;
}
 .banner-text h1 {
 font-size: 42px;
}
 .banner-text p {
 font-size: 18px;
}
 .footer .footer-col {
 margin-bottom: 50px;
}
}
@media screen and (max-width: 640px) {
 .banner-text {
 padding-top: 35%;
}
}
@media screen and (max-width: 480px) {
 .banner-text {
 padding-top: 45%;
}
 .banner-text h1 {
 font-size: 32px;
}
 .item {
 width:70%;
}
}
@media screen and (max-width: 320px) {
 .banner-text {
 padding-top: 55%;
}
 .item {
 width:70%;
}
}
