/* ------------------------------------------------------------------------------
	Template Name: Orly
	Author: Designstub
	Author URI: http://www.designstub.com
	License: GNU General Public License version 3.0
	License URI: http://www.gnu.org/licenses/gpl-3.0.html
	Version: 1.0

/* ------------------------------------------------------------------------------
	Typography
-------------------------------------------------------------------------------*/

@import url(http://fonts.googleapis.com/css?family=Dosis:300,400,500,600,700);
@import url(http://fonts.googleapis.com/css?family=Roboto:300,400,500,600,700);

p {
	font-size: 14px;
	line-height: 22.4px;
	color: #6c7279;
}
h1 {
	font-size: 65px;
	color: #2d3033;
}
h2 {
	font-size: 40px;
	color: #2d3033;
}
h3 {
	font-size: 28px;
	color: #2d3033;
	font-weight: 300;
}
h4 {
	font-size: 22px;
	color: #2d3033;
	font-weight: 400;
}
h5 {
	font-size: 14px;
	color: #2d3033;
	text-transform: uppercase;
	font-weight: 700;
}
.btn {
	color: #fff;
	font-size: 13px;
	font-weight: 600;
	border-bottom:3px solid rgba(255, 255, 255, 0.3);
	-moz-border-radius: 0px;
	-webkit-border-radius: 0px;
	border-radius: 0px;
	letter-spacing:3px;
	line-height:30px;
	display: inline-block;
	text-transform: uppercase;
}
.btn:hover, .btn:focus {
	color: #fff;
	border-bottom:3px solid rgba(229, 46, 46, 1);
}
.btn-large {
	padding: 15px 40px;
}
/* ------------------------------------------------------------------------------
	Global Styles
-------------------------------------------------------------------------------*/
a {
	color: #e84545;
}
a:hover, a:focus {
	text-decoration: none;
	-moz-transition: background-color, color, 0.3s;
	-o-transition: background-color, color, 0.3s;
	-webkit-transition: background-color, color, 0.3s;
	transition: background-color, color, 0.3s;
}
body {
	font-family: "Roboto", sans-serif;
	font-weight: 400;
	color: #6c7279;
}
ul, ol {
	margin: 0;
	padding: 0;
}
ul li {
	list-style: none;
}
.section {
	padding: 100px 0;
}
.no-padding {
	padding: 0;
}
 .no-gutter [class*=col-] {
 padding-right: 0;
 padding-left: 0;
}

/* ------------------------------------------------------------------------------
	Banner
-------------------------------------------------------------------------------*/

.logo {
	color: rgba(255, 255, 255, 1);
	font-family: "Dosis", sans-serif;
	font-weight: 700;
	font-size:22px;
	letter-spacing:3px;
	text-transform: uppercase;
	border:1px solid rgba(255, 255, 255, 0.5);
	padding:10px 20px;
}
.banner-area {
	position: relative;
}
.banner-area-gradient {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	opacity: 0.7;
	background: rgb(27,19,19);
}
.banner-text {
	padding-top: 12%;
	padding-bottom: 12%;
}
.banner-text h1 {
	margin-top:10%;
	color: #fff;
	font-family: "Dosis", sans-serif;
	font-weight: 100;
	letter-spacing:21px;
	font-size:19px;
	text-transform: uppercase;
}
.banner-text p {
	color: rgba(255, 255, 255, 0.5);
	font-size: 16px;
	font-weight: 300;
	line-height: 1.5;
	letter-spacing:3px;
	margin-bottom: 5%;
}

/* ------------------------------------------------------------------------------
	Countdown
-------------------------------------------------------------------------------*/

#countdown {
	padding:0;
	position:relative;
	margin-top:5%;
	margin-bottom:5%;
}
.item {
	display: inline-block;
	position: relative;
	text-align:center;
	margin:0 10px;
	padding:2%;
	text-transform:uppercase;
	font-size:13px;
	border-top:1px solid rgba(255, 255, 255, 0.1);
	border-bottom:1px solid rgba(255, 255, 255, 0.1);
}
.item p {
	font-family: "Dosis", sans-serif;
	text-align:center;
	margin:0;
	font-size:27px;
	padding:0;
}

/* ------------------------------------------------------------------------------
	Introduction
-------------------------------------------------------------------------------*/


  .intro-content {
	margin-top: 20px;
}
.intro h1 {
	font-family: "Dosis", sans-serif;
	font-size:33px;
	font-weight: 700;
}
.intro h2 {
	font-family: "Dosis", sans-serif;
	font-size:17px;
	font-weight: 700;
	letter-spacing:2px;
	text-transform:uppercase;
}
.intro p {
	font-size:15px;
	font-weight: 300;
	letter-spacing:1px;
	line-height:27px;
}

/* ------------------------------------------------------------------------------
	Subscribe
-------------------------------------------------------------------------------*/

	.subscribe {
	width: 100%;
	background-color: #eee;
	background-image: url('../images/backgrounds/parallax-bg.jpg');
	background-attachment: fixed;
	background-repeat: no-repeat;
	background-position: 50% 0;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover;
	background-size: cover;
	position: relative;
}
.subscribe >.container {
	padding-top: 80px;
	padding-bottom: 80px;
}
.subscribe-title h2 {
	font-family:"Dosis", sans-serif;
	font-weight: 600;
	font-size: 23px;
	color: #fff;
	letter-spacing:3px;
	margin:0 3%;
	line-height:70px;
	text-transform:uppercase;
}
.subscribe-form {
	margin-top: 6px;
}
.subscribe-form input[type=text] {
	width: 65%;
	height: 60px;
	display: block;
	padding: 0 20px;
	background-color: #fff;
	border: 1px solid #fff;
	-webkit-border-top-left-radius: 2px;
	-webkit-border-bottom-left-radius: 2px;
	-moz-border-radius-topleft: 2px;
	-moz-border-radius-bottomleft: 2px;
	border-top-left-radius: 2px;
	border-bottom-left-radius: 2px;
	line-height: 60px;
	letter-spacing:1px;
	font-size:15px;
	font-weight:300;
	float: left;
}
.subscribe-form input:focus {
	outline: 0;
}
.subscribe-form input[type=submit] {
	width: 35%;
	height: 60px;
	display: block;
	padding: 0 10px;
	background-color: #fc6e51;
	border: 1px solid #fc6e51;
	color: #fff;
	-webkit-border-top-right-radius: 2px;
	-webkit-border-bottom-right-radius: 2px;
	-moz-border-radius-topright: 2px;
	-moz-border-radius-bottomright: 2px;
	border-top-right-radius: 2px;
	border-bottom-right-radius: 2px;
	font-family: 'Open Sans', sans-serif;
	font-weight: 700;
	transition: all 0.125s ease-in-out 0s;
	-moz-transition: all 0.125s ease-in-out 0s;
	-webkit-transition: all 0.125s ease-in-out 0s;
	-o-transition: all 0.125s ease-in-out 0s;
	-ms-transition: all 0.125s ease-in-out 0s;
	float: right;
}
.subscribe-form input[type=submit]:hover {
	background-color: #e85a3d;
	border: 1px solid #e85a3d;
	color: #fff;
}

.error_message {
	color:#fc6e51;
	padding-bottom:15px;
	font-size:13px;
	line-height:30px;
}

#success_page {
	color:#9ce726;
	padding-bottom:10px;
	font-size:12px;
}
#success_page h3 {
	font-size:17px;
	font-weight:400px;
	color:#4ab217;
}
#success_page p {
	font-size:12px;
	font-weight:400px;
	color:#b3b3b3;
}
/* ------------------------------------------------------------------------------
	 Footer
-------------------------------------------------------------------------------*/
.footer {
	text-align: left;
	background-color: #181818;
	padding:50px 0 50px 0;
}


.footer h5 {
	color: #fff;
}
.footer h5 {
	margin-bottom: 20px;
}
.footer p {
	color: rgba(255, 255, 255, 0.25);
	font-size:12px;
	line-height:14px;
}
.footer a {
	color: rgba(255, 255, 255, 0.50);
}
.footer a:hover {
	color: #e84545;
}
.footer .footer-share {
	margin-top: 0;
}
.footer .footer-share li {
	display: inline-block;
	float: none;
}
.footer .footer-share a {
	border: none;
	font-size: 17px;
	letter-spacing:20px;
	color: rgba(255, 255, 255, 0.25);
}
.footer .fa-heart {
	color: #e84545;
	font-size: 11px;
	margin: 0 2px;
}
